/*
** Module   : SOAPEntity.java
** Abstract : Interface grouping common attributes for SOAP-FAULT-DETAIL and SOAP-HEADER-ENTRYREF.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --------------------------------Description-----------------------------------
** 001 CA  20130216 Created initial version.
*/

package com.goldencode.p2j.util;

/**
 * Interface describing the common features for SOAP-FAULT-DETAIL and SOAP-HEADER-ENTRYREF
 * resources:
 * <ul>
 *    <li>{@link #getNode GET-NODE method}</li>
 *    <li>{@link #getSerialized GET-SERIALIZED method}</li>
 * </ul>
 */
public interface SOAPEntity
{
   /**
    * Gets the X-NODEREF object that refers to the XML underlying a SOAP-HEADER-ENTRYREF object or
    * SOAP-FAULT entry and sets it to the given handle.
    * <p>
    * This method returns a logical even though the Progress 4GL documentation explicitly states 
    * otherwise. Actual working code has proven that the original documentation is incorrect. 
    * This implementation matches the actual runtime behavior of the 4GL.
    * 
    * @param    xNode
    *           The handle where the resource will be set.
    *           
    * @return   <code>true</code> if the operation was possible.
    */
   public logical getNode(handle xNode);

   /**
    * Returns a LONGCHAR that contains the serialized form of the XML underlying 
    * SOAP-HEADER-ENTRYREF or SOAP-FAULT entry.
    * 
    * @return   See above.
    */
   public longchar getSerialized();
}
